#' gendercoder: A Package for Recoding Freetext Gender Data
#'
#' Provides dictionaries and \code{recode_gender()} to allow for easy automatic coding of common variations in free-text responses to the question \strong{"What is your gender?"}
#'
#' @docType package
#' @name gendercoder
NULL

#' sample
#'
#' A sample data.frame of free-text gender in English for testing and demonstration
#'
#' @name sample
#' @docType data
NULL

#' manylevels_en
#'
#' An English dictionary for the recode_gender function that has many levels
#'
#' @name manylevels_en
#' @docType data
NULL

#' fewlevels_en
#'
#' An English dictionary for the recode_gender function that has fewer levels
#'
#' @name fewlevels_en
#' @docType data
NULL
