% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gendercodeR.R
\docType{data}
\name{fewlevels_en}
\alias{fewlevels_en}
\title{fewlevels_en}
\description{
An English dictionary for the recode_gender function that has fewer levels
}
