% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gendercodeR.R
\docType{data}
\name{manylevels_en}
\alias{manylevels_en}
\title{manylevels_en}
\description{
An English dictionary for the recode_gender function that has many levels
}
