% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gendercodeR.R
\docType{data}
\name{sample}
\alias{sample}
\title{sample}
\description{
A sample data.frame of free-text gender in English for testing and demonstration
}
